@@ -21,13 +21,12 @@
 #include "k3bglobals.h"
 #include "k3bmediacache.h"
 #include "k3bmedium.h"
+#include "k3b_i18n.h"
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <kstandarddirs.h>
-
-#include <qfile.h>
-#include <qfileinfo.h>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
 
 
 class K3b::VideoDVDTitleTranscodingJob::Private
@@ -55,7 +54,7 @@ bool K3b::VideoDVDTitleTranscodingJob::Private::getEncodedFrames( const QString&
     int pos1 = 0;
     int pos2 = 0;
 
-    if ( usedTranscodeBin->version >= Version( 1, 1, 0 ) ) {
+    if ( usedTranscodeBin->version() >= Version( 1, 1, 0 ) ) {
         // encoding=1 frame=1491 first=0 last=-1 fps=14.815 done=-1.000000 timestamp=59.640 timeleft=-1 decodebuf=12 filterbuf=5 encodebuf=3
         if( line.startsWith( "encoding=" ) ) {
             pos1 = line.indexOf( '=', 9 );
@@ -129,21 +128,21 @@ void K3b::VideoDVDTitleTranscodingJob::start()
         return;
     }
 
-    if( d->usedTranscodeBin->version < K3b::Version( 1, 0, 0 ) ){
+    if( d->usedTranscodeBin->version() < K3b::Version( 1, 0, 0 ) ){
         emit infoMessage( i18n("%1 version %2 is too old."
                                ,QString("transcode")
-                               ,d->usedTranscodeBin->version), MessageError );
+                               ,d->usedTranscodeBin->version()), MessageError );
         jobFinished( false );
         return;
     }
 
-    emit debuggingOutput( QLatin1String( "Used versions" ), QLatin1String( "transcode: " ) + d->usedTranscodeBin->version );
+    emit debuggingOutput( QLatin1String( "Used versions" ), QString::fromLatin1( "transcode: %1" ).arg(d->usedTranscodeBin->version()) );
 
-    if( !d->usedTranscodeBin->copyright.isEmpty() )
-        emit infoMessage( i18n("Using %1 %2 - Copyright (C) %3"
+    if( !d->usedTranscodeBin->copyright().isEmpty() )
+        emit infoMessage( i18n("Using %1 %2 – Copyright © %3"
                                ,d->usedTranscodeBin->name()
-                               ,d->usedTranscodeBin->version
-                               ,d->usedTranscodeBin->copyright), MessageInfo );
+                               ,d->usedTranscodeBin->version()
+                               ,d->usedTranscodeBin->copyright()), MessageInfo );
 
     //
     // Let's take a look at the filename
@@ -155,7 +154,7 @@ void K3b::VideoDVDTitleTranscodingJob::start()
         // let's see if the directory exists and we can write to it
         QFileInfo fileInfo( m_filename );
         QFileInfo dirInfo( fileInfo.path() );
-        if( !dirInfo.exists() && !KStandardDirs::makeDir( dirInfo.absoluteFilePath() ) ) {
+        if( !dirInfo.exists() && !QDir().mkpath( dirInfo.absoluteFilePath() ) ) {
             emit infoMessage( i18n("Unable to create folder '%1'",dirInfo.filePath()), MessageError );
             return;
         }
@@ -199,7 +198,7 @@ void K3b::VideoDVDTitleTranscodingJob::startTranscode( int pass )
         break;
 
     default:
-        emit infoMessage( i18n("Invalid Video codec set: %1",m_videoCodec), MessageError );
+        emit infoMessage( i18n("Invalid video codec set: %1",m_videoCodec), MessageError );
         jobFinished( false );
         return;
     }
@@ -222,7 +221,7 @@ void K3b::VideoDVDTitleTranscodingJob::startTranscode( int pass )
         break;
 
     default:
-        emit infoMessage( i18n("Invalid Audio codec set: %1",m_audioCodec), MessageError );
+        emit infoMessage( i18n("Invalid audio codec set: %1",m_audioCodec), MessageError );
         jobFinished( false );
         return;
     }
@@ -237,8 +236,8 @@ void K3b::VideoDVDTitleTranscodingJob::startTranscode( int pass )
     d->process = new K3b::Process();
     d->process->setSuppressEmptyLines(true);
     d->process->setSplitStdout(true);
-    connect( d->process, SIGNAL(stdoutLine(const QString&)), this, SLOT(slotTranscodeStderr(const QString&)) );
-    connect( d->process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotTranscodeExited(int, QProcess::ExitStatus)) );
+    connect( d->process, SIGNAL(stdoutLine(QString)), this, SLOT(slotTranscodeStderr(QString)) );
+    connect( d->process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotTranscodeExited(int,QProcess::ExitStatus)) );
 
     // the executable
     *d->process << d->usedTranscodeBin;
@@ -247,12 +246,12 @@ void K3b::VideoDVDTitleTranscodingJob::startTranscode( int pass )
     if( m_lowPriority )
         *d->process << "--nice" << "19";
 
-    if ( d->usedTranscodeBin->version >= Version( 1, 1, 0 ) )
+    if ( d->usedTranscodeBin->version() >= Version( 1, 1, 0 ) )
         *d->process << "--log_no_color";
 
     // we only need 100 steps, but to make sure we use 150
     int progressRate = qMax( 1, ( int )m_dvd[m_titleNumber-1].playbackTime().totalFrames()/150 );
-    if ( d->usedTranscodeBin->version.simplify() >= K3b::Version( 1, 1, 0 ) )
+    if ( d->usedTranscodeBin->version().simplify() >= K3b::Version( 1, 1, 0 ) )
         *d->process << "--progress_meter" << "2" << "--progress_rate" << QString::number(progressRate);
     else
         *d->process << "--print_status" << QString::number(progressRate);
@@ -303,7 +302,7 @@ void K3b::VideoDVDTitleTranscodingJob::startTranscode( int pass )
         }
 
         // the output filename
-        *d->process << "-o" << QString("\"%1\"").arg(m_filename);
+        *d->process << "-o" << m_filename;
     }
     else {
         // gather information about the video stream, ignore audio
@@ -372,9 +371,9 @@ void K3b::VideoDVDTitleTranscodingJob::startTranscode( int pass )
         *d->process << *it;
 
     // produce some debugging output
-    kDebug() << "***** transcode parameters:\n";
+    qDebug() << "***** transcode parameters:\n";
     QString s = d->process->joinedArgs();
-    kDebug() << s << flush;
+    qDebug() << s << flush;
     emit debuggingOutput( d->usedTranscodeBin->name() + " command:", s);
 
     // start the process
@@ -618,4 +617,4 @@ bool K3b::VideoDVDTitleTranscodingJob::transcodeBinaryHasSupportFor( K3b::VideoD
     return bin->hasFeature( QString::fromLatin1( s_codecFeatures[(int)codec] ) );
 }
 
-#include "k3bvideodvdtitletranscodingjob.moc"
+
